@@ -510,4 +510,33 @@ def test_equals_different_type(other):
 
 def test_from_user_input_custom_crs_class():
     """Support comparison to foreign objects that provide to_wkt()"""
-    assert CRS.from_user_input(CustomCRS()) == CRS.from_epsg(4326)
\ No newline at end of file
+    assert CRS.from_user_input(CustomCRS()) == CRS.from_epsg(4326)
+
+
+def test_from_string__wkt_with_proj():
+    wkt = (
+        'PROJCS["WGS 84 / Pseudo-Mercator",'
+        'GEOGCS["WGS 84",'
+        '    DATUM["WGS_1984",'
+        '        SPHEROID["WGS 84",6378137,298.257223563,'
+        '            AUTHORITY["EPSG","7030"]],'
+        '        AUTHORITY["EPSG","6326"]],'
+        '    PRIMEM["Greenwich",0,'
+        '        AUTHORITY["EPSG","8901"]],'
+        '    UNIT["degree",0.0174532925199433,'
+        '        AUTHORITY["EPSG","9122"]],'
+        '    AUTHORITY["EPSG","4326"]],'
+        'PROJECTION["Mercator_1SP"],'
+        'PARAMETER["central_meridian",0],'
+        'PARAMETER["scale_factor",1],'
+        'PARAMETER["false_easting",0],'
+        'PARAMETER["false_northing",0],'
+        'UNIT["metre",1,'
+        '    AUTHORITY["EPSG","9001"]],'
+        'AXIS["Easting",EAST],'
+        'AXIS["Northing",NORTH],'
+        'EXTENSION["PROJ4","+proj=merc +a=6378137 +b=6378137 +lat_ts=0 '
+        '+lon_0=0 +x_0=0 +y_0=0 +k=1 +units=m +nadgrids=@null +wktext +no_defs"],'
+        'AUTHORITY["EPSG","3857"]] '
+    )
+    assert CRS.from_string(wkt).to_epsg() == 3857
